'use strict';

var _expect = require('expect.js');

var _expect2 = _interopRequireDefault(_expect);

var _jss = require('jss');

var _cssVendor = require('css-vendor');

var _cssVendor2 = _interopRequireDefault(_cssVendor);

var _index = require('./index');

var _index2 = _interopRequireDefault(_index);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

describe('jss-vendor-prefixer', function () {
  var jss = void 0;

  beforeEach(function () {
    jss = (0, _jss.create)().use((0, _index2['default'])());
  });

  describe('prefixed property', function () {
    var sheet = void 0;

    beforeEach(function () {
      sheet = jss.createStyleSheet({
        a: { animation: 'yyy' }
      }, { named: false });
    });

    it('should generate correct CSS', function () {
      var prefixedProp = _cssVendor2['default'].supportedProperty('animation');
      (0, _expect2['default'])(sheet.toString()).to.be('a {\n  ' + prefixedProp + ': yyy;\n}');
    });
  });

  describe('@keyframes', function () {
    var sheet = void 0;

    beforeEach(function () {
      sheet = jss.createStyleSheet({
        '@keyframes a': {}
      }, { named: false });
    });

    it('should generate correct CSS', function () {
      var prefixedKeyframes = '@' + _cssVendor2['default'].prefix.css + 'keyframes';
      (0, _expect2['default'])(sheet.toString()).to.be(prefixedKeyframes + ' a {\n}');
    });
  });

  describe('unknown property', function () {
    var sheet = void 0;

    beforeEach(function () {
      sheet = jss.createStyleSheet({
        a: { xxx: 'block' }
      }, { named: false });
    });

    it('should generate correct CSS', function () {
      (0, _expect2['default'])(sheet.toString()).to.be('a {\n  xxx: block;\n}');
    });
  });

  describe('unknown value', function () {
    var sheet = void 0;

    beforeEach(function () {
      sheet = jss.createStyleSheet({
        a: { display: 'yyy' }
      }, { named: false });
    });

    it('should generate correct CSS', function () {
      (0, _expect2['default'])(sheet.toString()).to.be('a {\n  display: yyy;\n}');
    });
  });

  describe('unknown property and value', function () {
    var sheet = void 0;

    beforeEach(function () {
      sheet = jss.createStyleSheet({
        a: { xxx: 'yyy' }
      }, { named: false });
    });

    it('should generate correct CSS', function () {
      (0, _expect2['default'])(sheet.toString()).to.be('a {\n  xxx: yyy;\n}');
    });
  });

  describe('prefixed value', function () {
    var sheet = void 0;

    beforeEach(function () {
      sheet = jss.createStyleSheet({
        a: { display: 'flex' }
      }, { named: false });
    });

    it('should generate correct CSS', function () {
      var supportedValue = _cssVendor2['default'].supportedValue('display', 'flex');
      (0, _expect2['default'])(sheet.toString()).to.be('a {\n  display: ' + supportedValue + ';\n}');
    });
  });
});